@@ -6,7 +6,9 @@ from . import time_funcs
 from . import utils
 from . import plotting 
 from . import water_balance
+from . import spatial_validation
+from . import ensembles
 
 __author__ = """Jannis M. Hoch"""
 __email__ = 'j.m.hoch@uu.nl'
-__version__ = '0.1.4.2'
+__version__ = '0.1.5'
